@@ -1,10 +1,10 @@
 `ME.dfbetas` <-
-function(estex, parameters=0, plot=FALSE, ...) 
+function(estex, parameters=0, plot=FALSE, sort=FALSE, to.sort=NA, abs=FALSE, ...) 
 	{
 		
 		if(plot==TRUE)
 			{
-			dp.ME.dfbetas(estex, parameters=parameters, ...)
+			dp.ME.dfbetas(estex, parameters=parameters, sort=sort, to.sort=to.sort, abs=abs, ...)
 			}
 	
 		n.groups <- dim(estex$alt.fixed)[1]
@@ -24,15 +24,32 @@ function(estex, parameters=0, plot=FALSE, ...)
 			}
 		
 		if(n.groups > 1)
-		{
+			{
 			for (i in 1:n.groups) 
 				{
-					e[i,] <- (a-b[i,]) / c[i,]
+				e[i,] <- (a-b[i,]) / c[i,]
 				}
 			dimnames(e) <- dimnames(estex$alt.fixed[, sel])
-		}	
+			}	
 		
+		if(abs == TRUE)
+			{
+			e <- abs(e)
+			}
 		
+		if(sort == TRUE)
+			{
+			if(dim(e)[2] == 1)
+				{
+				to.sort <- colnames(e)
+				}
+	
+			if(dim(e)[2] > 1 & is.na(to.sort))
+				{
+				stop("Indicate on which variable to sort the DFBETAS: please specify to.sort")
+				}
+			e <- e[order(e[, to.sort]), ]
+			}
 
 		return(e)
-	}
\ No newline at end of file
+	}
